@@ -84,6 +84,9 @@ SERVICE_VERSIONS = {
     "bm": [
         "2018-04-23"
     ],
+    "bma": [
+        "2021-06-24"
+    ],
     "bmeip": [
         "2018-06-25"
     ],
@@ -207,6 +210,9 @@ SERVICE_VERSIONS = {
     "dasb": [
         "2019-10-18"
     ],
+    "dataintegration": [
+        "2022-06-13"
+    ],
     "dayu": [
         "2018-07-09"
     ],
@@ -346,12 +352,17 @@ SERVICE_VERSIONS = {
         "2019-04-11"
     ],
     "iotvideo": [
+        "2021-11-25",
         "2020-12-15",
         "2019-11-26"
     ],
     "iotvideoindustry": [
         "2020-12-01"
     ],
+    "irp": [
+        "2022-08-05",
+        "2022-03-24"
+    ],
     "ivld": [
         "2021-09-03"
     ],
@@ -439,12 +450,18 @@ SERVICE_VERSIONS = {
     "privatedns": [
         "2020-10-28"
     ],
+    "pts": [
+        "2021-07-28"
+    ],
     "rce": [
         "2020-11-03"
     ],
     "redis": [
         "2018-04-12"
     ],
+    "region": [
+        "2022-06-27"
+    ],
     "rkp": [
         "2019-12-09"
     ],
@@ -624,6 +641,7 @@ SERVICE_VERSIONS = {
         "2020-09-18"
     ],
     "vm": [
+        "2021-09-22",
         "2020-12-29",
         "2020-07-09"
     ],
